==> ejc-bfyjerp-api-3.0.0-20241114.085716-37-sources.jar: com/ejianc/business/oa/vo/CertHumanVO.java <==
package com.ejianc.business.oa.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 人力行政-证书人员申请表
 * 
 * @author generator
 * 
 */
public class CertHumanVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 编号
    private String name; // 员工名称
    private Integer sex; // 性别 1：男 2：女
    private Integer age; // 年龄
    private Long orgId; // 组织ID
    private String orgName; // 组织
    private Integer humanType; // 人员类别
    private String humanTypeName; // 人员类别
    private String idCard; // 身份证号码
    private String compatibility; // 配合度
    private String cert; // 证书情况
    private String certName; // 证书情况
    private BigDecimal certMny; // 证书费用
    private Integer payType; // 付款方式
    private String payTypeName; // 付款方式
    private Integer titleQuery; // 职称网查
    private String titleQueryName; // 职称网查
    private String changeCode; // 变更单号
    private Long changeId; // 变更主键
    private Integer changeStatus; // 变更状态(1-未变更 2-变更中 3-已变更)
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Integer changeVersion; // 变更版本
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public Integer getAge() {
        return age;
    }

    public void setAge(Integer age) {
        this.age = age;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getHumanType() {
        return humanType;
    }

    public void setHumanType(Integer humanType) {
        this.humanType = humanType;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public String getIdCard() {
        return idCard;
    }

    public String getCompatibility() {
        return compatibility;
    }

    public void setCompatibility(String compatibility) {
        this.compatibility = compatibility;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public String getCert() {
        return cert;
    }
    @ReferDeserialTransfer
    public void setCert(String cert) {
        this.cert = cert;
    }
    public String getCertName() {
        return certName;
    }

    public void setCertName(String certName) {
        this.certName = certName;
    }
    public BigDecimal getCertMny() {
        return certMny;
    }

    public void setCertMny(BigDecimal certMny) {
        this.certMny = certMny;
    }
    public Integer getPayType() {
        return payType;
    }

    public void setPayType(Integer payType) {
        this.payType = payType;
    }
    public String getPayTypeName() {
        return payTypeName;
    }

    public void setPayTypeName(String payTypeName) {
        this.payTypeName = payTypeName;
    }
    public Integer getTitleQuery() {
        return titleQuery;
    }

    public void setTitleQuery(Integer titleQuery) {
        this.titleQuery = titleQuery;
    }
    public String getTitleQueryName() {
        return titleQueryName;
    }

    public void setTitleQueryName(String titleQueryName) {
        this.titleQueryName = titleQueryName;
    }
    public String getChangeCode() {
        return changeCode;
    }

    public void setChangeCode(String changeCode) {
        this.changeCode = changeCode;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Integer getChangeStatus() {
        return changeStatus;
    }

    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20241120.022153-44-sources.jar: com/ejianc/business/oa/vo/CertHumanVO.java <==
package com.ejianc.business.oa.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 人力行政-证书人员申请表
 * 
 * @author generator
 * 
 */
public class CertHumanVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 编号
    private String name; // 员工名称
    private Integer sex; // 性别 1：男 2：女
    private String sexName; // 性别 1：男 2：女
    private Integer age; // 年龄
    private Long orgId; // 组织ID
    private String orgName; // 组织
    private Integer humanType; // 人员类别
    private String humanTypeName; // 人员类别
    private String idCard; // 身份证号码
    private String compatibility; // 配合度
    private String cert; // 证书情况
    private String certName; // 证书情况
    private BigDecimal certMny; // 证书费用
    private Integer payType; // 付款方式
    private String payTypeName; // 付款方式
    private Integer titleQuery; // 职称网查
    private String titleQueryName; // 职称网查
    private String changeCode; // 变更单号
    private Long changeId; // 变更主键
    private Integer changeStatus; // 变更状态(1-未变更 2-变更中 3-已变更)
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Integer changeVersion; // 变更版本
    private String changeStatusName; // 变更状态

    public String getSexName() {
        return sexName;
    }

    public void setSexName(String sexName) {
        this.sexName = sexName;
    }

    public String getChangeStatusName() {
        return changeStatusName;
    }

    public void setChangeStatusName(String changeStatusName) {
        this.changeStatusName = changeStatusName;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public Integer getAge() {
        return age;
    }

    public void setAge(Integer age) {
        this.age = age;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getHumanType() {
        return humanType;
    }

    public void setHumanType(Integer humanType) {
        this.humanType = humanType;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public String getIdCard() {
        return idCard;
    }

    public String getCompatibility() {
        return compatibility;
    }

    public void setCompatibility(String compatibility) {
        this.compatibility = compatibility;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public String getCert() {
        return cert;
    }
    @ReferDeserialTransfer
    public void setCert(String cert) {
        this.cert = cert;
    }
    public String getCertName() {
        return certName;
    }

    public void setCertName(String certName) {
        this.certName = certName;
    }
    public BigDecimal getCertMny() {
        return certMny;
    }

    public void setCertMny(BigDecimal certMny) {
        this.certMny = certMny;
    }
    public Integer getPayType() {
        return payType;
    }

    public void setPayType(Integer payType) {
        this.payType = payType;
    }
    public String getPayTypeName() {
        return payTypeName;
    }

    public void setPayTypeName(String payTypeName) {
        this.payTypeName = payTypeName;
    }
    public Integer getTitleQuery() {
        return titleQuery;
    }

    public void setTitleQuery(Integer titleQuery) {
        this.titleQuery = titleQuery;
    }
    public String getTitleQueryName() {
        return titleQueryName;
    }

    public void setTitleQueryName(String titleQueryName) {
        this.titleQueryName = titleQueryName;
    }
    public String getChangeCode() {
        return changeCode;
    }

    public void setChangeCode(String changeCode) {
        this.changeCode = changeCode;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Integer getChangeStatus() {
        return changeStatus;
    }

    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }
    
}
